@@ -1,10 +1,9 @@
 package configobservercontroller
 
 import (
+	configinformers "github.com/openshift/client-go/config/informers/externalversions"
 	"k8s.io/client-go/tools/cache"
 
-	configinformers "github.com/openshift/client-go/config/informers/externalversions"
-	operatorv1informers "github.com/openshift/client-go/operator/informers/externalversions"
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/configobservation"
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/configobservation/scheduler"
 	"github.com/openshift/cluster-kube-scheduler-operator/pkg/operator/operatorclient"
@@ -20,12 +19,12 @@ type ConfigObserver struct {
 
 func NewConfigObserver(
 	operatorClient v1helpers.OperatorClient,
-	operatorConfigInformers operatorv1informers.SharedInformerFactory,
 	kubeInformersForNamespaces v1helpers.KubeInformersForNamespaces,
 	configInformer configinformers.SharedInformerFactory,
 	resourceSyncer resourcesynccontroller.ResourceSyncer,
 	eventRecorder events.Recorder,
 ) *ConfigObserver {
+
 	interestingNamespaces := []string{
 		operatorclient.GlobalUserSpecifiedConfigNamespace,
 		operatorclient.GlobalMachineSpecifiedConfigNamespace,
@@ -37,7 +36,6 @@ func NewConfigObserver(
 	for _, ns := range interestingNamespaces {
 		configMapPreRunCacheSynced = append(configMapPreRunCacheSynced, kubeInformersForNamespaces.InformersFor(ns).Core().V1().ConfigMaps().Informer().HasSynced)
 	}
-
 	c := &ConfigObserver{
 		ConfigObserver: configobserver.NewConfigObserver(
 			operatorClient,
@@ -47,19 +45,18 @@ func NewConfigObserver(
 				ConfigmapLister: kubeInformersForNamespaces.ConfigMapLister(),
 				ResourceSync:    resourceSyncer,
 				PreRunCachesSynced: append(configMapPreRunCacheSynced,
-					operatorConfigInformers.Operator().V1().KubeSchedulers().Informer().HasSynced,
+					operatorClient.Informer().HasSynced,
 					configInformer.Config().V1().Schedulers().Informer().HasSynced,
 				),
 			},
 			scheduler.ObserveSchedulerConfig,
 		),
 	}
-
-	operatorConfigInformers.Operator().V1().KubeSchedulers().Informer().AddEventHandler(c.EventHandler())
+	operatorClient.Informer().AddEventHandler(c.EventHandler())
 	for _, ns := range interestingNamespaces {
 		kubeInformersForNamespaces.InformersFor(ns).Core().V1().ConfigMaps().Informer().AddEventHandler(c.EventHandler())
 	}
-	configInformer.Config().V1().Schedulers().Informer().AddEventHandler(c.EventHandler())
 
+	configInformer.Config().V1().Schedulers().Informer().AddEventHandler(c.EventHandler())
 	return c
 }
